TermsSpan class

Constructors

TermsSpan({String text = '', List<String> types = const []})
const
TermsSpan.from(Object? source)
factory

Properties

fontSize → double?
no setter
fontStyle → FontStyle?
no setter
fontWeight → FontWeight?
no setter
hashCode → int
The hash code for this object.
no setterinherited
isBold → bool
no setter
isItalic → bool
no setter
isUnderline → bool
no setter
json → Map<String, dynamic>
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String
final
textDecoration → TextDecoration?
no setter
types → List<String>
final

Methods

copyWith({String? text, List<String>? types}) → TermsSpan
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited